/*
 *
 *    Copyright (c) 2023 Project CHIP Authors
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

#pragma once

#include "silabs_utils.h"

// ---- Smoke CO Alarm Example App Config ----

#define APP_TASK_NAME "Alm"

#define BLE_DEV_NAME "SiLabs-Alarm"

// Time it takes in ms for the simulated actuator to move from one
// state to another.
#define ACTUATOR_MOVEMENT_PERIOS_MS 10

#define ON_DEMO_BITMAP                                                                                                             \
    0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,  \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0xFF, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xE0,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0x3F, 0x00, 0x00, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0xFE, 0xFF, 0xFF, 0xFF,    \
        0x07, 0x00, 0x00, 0x00, 0xFC, 0xFF, 0xFF, 0xFF, 0x01, 0xE0, 0xFF, 0x00, 0xF0, 0xFF, 0xFF, 0xFF, 0x00, 0xFC, 0xFF, 0x07,    \
        0xE0, 0xFF, 0xFF, 0x7F, 0x00, 0xFF, 0xFF, 0x1F, 0xC0, 0xFF, 0xFF, 0x7F, 0x80, 0xFF, 0xFF, 0x7F, 0x80, 0xFF, 0xFF, 0x3F,    \
        0xE0, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0x1F, 0xF0, 0x7F, 0xC0, 0xFF, 0x01, 0xFF, 0xFF, 0x0F, 0xF8, 0x0F, 0x00, 0xFE,    \
        0x03, 0xFE, 0xFF, 0x0F, 0xFC, 0x03, 0x00, 0xF8, 0x07, 0xFC, 0xFF, 0x07, 0xFE, 0xC3, 0x7F, 0xF8, 0x0F, 0xFC, 0x07, 0x07,    \
        0xFE, 0xF7, 0xFF, 0xFF, 0x0F, 0xF8, 0x07, 0x03, 0xFF, 0xFF, 0xE1, 0xFF, 0x1F, 0xF8, 0x07, 0x03, 0xFF, 0x3F, 0x80, 0xFF,    \
        0x3F, 0xF8, 0x07, 0x81, 0xDF, 0x3F, 0x80, 0x7F, 0x3F, 0xF0, 0x07, 0x81, 0x9F, 0x7F, 0xDF, 0x3F, 0x7E, 0xF0, 0x07, 0xC1,    \
        0x8F, 0xFF, 0xFF, 0x3F, 0x7E, 0xF0, 0x07, 0xC0, 0xCF, 0xFF, 0xFF, 0x7F, 0x7C, 0xE0, 0x07, 0xC0, 0xC7, 0xFD, 0xFF, 0x77,    \
        0x7C, 0xE0, 0x07, 0xC0, 0xC7, 0xF9, 0xFF, 0xE3, 0xFC, 0xE0, 0x07, 0xE0, 0xC7, 0xF8, 0xF3, 0xE3, 0xFC, 0xE0, 0x07, 0xE0,    \
        0xE7, 0xF8, 0xE0, 0xE7, 0xFC, 0xE0, 0x07, 0xE0, 0xE7, 0xF8, 0xE0, 0xE7, 0xF8, 0xE0, 0x07, 0xE0, 0xE7, 0xF8, 0xE0, 0xE7,    \
        0xF8, 0xE0, 0x07, 0xE0, 0xE7, 0xF8, 0xE0, 0xE7, 0xF8, 0xE0, 0x07, 0xE0, 0xC7, 0xF8, 0xF3, 0xE3, 0xFC, 0xE0, 0x07, 0xC0,    \
        0xC7, 0xF9, 0xFF, 0xE3, 0xFC, 0xE0, 0xFF, 0xC0, 0xC7, 0xFD, 0xFF, 0x77, 0xFC, 0xE0, 0xFF, 0xC1, 0xCF, 0xFF, 0xFF, 0x7F,    \
        0x7C, 0xE0, 0xFF, 0xC1, 0x8F, 0xFF, 0xFF, 0x3F, 0x7E, 0xF0, 0xFF, 0x81, 0x9F, 0x7F, 0xDF, 0x3F, 0x7E, 0xF0, 0xFF, 0x81,    \
        0xDF, 0x3F, 0x80, 0x7F, 0x3F, 0xF0, 0x07, 0x03, 0xFF, 0x3F, 0x80, 0xFF, 0x3F, 0xF8, 0x07, 0x03, 0xFF, 0xFF, 0xF1, 0xFF,    \
        0x1F, 0xF8, 0x07, 0x07, 0xFE, 0xF7, 0xFF, 0xFF, 0x1F, 0xF8, 0x07, 0x07, 0xFE, 0xC3, 0xFF, 0xF8, 0x0F, 0xFC, 0x07, 0x0F,    \
        0xFC, 0x03, 0x00, 0xF8, 0x07, 0xFC, 0xFF, 0x0F, 0xF8, 0x0F, 0x00, 0xFE, 0x03, 0xFE, 0xFF, 0x1F, 0xF0, 0x7F, 0xC0, 0xFF,    \
        0x01, 0xFF, 0xFF, 0x3F, 0xE0, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0x7F, 0xC0, 0xFF, 0xFF, 0x7F, 0x80, 0xFF, 0xFF, 0xFF,    \
        0x00, 0xFF, 0xFF, 0x1F, 0xC0, 0xFF, 0xFF, 0xFF, 0x01, 0xFC, 0xFF, 0x07, 0xE0, 0xFF, 0xFF, 0xFF, 0x03, 0xE0, 0xFF, 0x00,    \
        0xF8, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0x00, 0x00, 0xFC, 0xFF, 0xFF, 0xFF, 0x0F, 0x00, 0x00, 0x00, 0xFE, 0xFF, 0xFF, 0xFF,    \
        0x3F, 0x00, 0x00, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0xFC,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF

#define OFF_DEMO_BITMAP                                                                                                            \
    0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,  \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0xFF, 0x3F, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x1F, 0x00, 0x00,    \
        0xF8, 0xFF, 0xFF, 0xFF, 0xFF, 0x07, 0x00, 0x00, 0xE0, 0xFF, 0xFF, 0xFF, 0xFF, 0x03, 0x00, 0x00, 0xC0, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x7F, 0x00, 0xF8, 0x1F, 0x00, 0xFE, 0xFF, 0xFF, 0x3F, 0x00, 0xFF, 0xFF,    \
        0x00, 0xFC, 0xFF, 0xFF, 0x1F, 0xE0, 0xFF, 0xFF, 0x07, 0xF8, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xFF,    \
        0x07, 0xF8, 0xFF, 0xFF, 0x1F, 0xE0, 0xFF, 0xFF, 0x03, 0xFE, 0x0F, 0xF0, 0x3F, 0xC0, 0xFF, 0xFF, 0x03, 0xFF, 0x01, 0x80,    \
        0xFF, 0xC0, 0xFF, 0xFF, 0x81, 0xFF, 0x00, 0x00, 0xFF, 0x80, 0xFF, 0xFF, 0x80, 0x7F, 0xF8, 0x1F, 0xFE, 0x81, 0xFF, 0xFF,    \
        0xC0, 0xFF, 0xFE, 0x7F, 0xFF, 0x03, 0xFF, 0x7F, 0xE0, 0xFF, 0x3F, 0xFC, 0xFF, 0x03, 0xFF, 0x7F, 0xE0, 0xFF, 0x07, 0xE0,    \
        0xFF, 0x07, 0xFE, 0x7F, 0xF0, 0xF7, 0x07, 0xE0, 0xEF, 0x07, 0xFE, 0x3F, 0xF0, 0xE3, 0xEF, 0xF7, 0xC7, 0x0F, 0xFE, 0x3F,    \
        0xF0, 0xF1, 0xFF, 0xFF, 0x8F, 0x0F, 0xFC, 0x3F, 0xF8, 0xF1, 0xFF, 0xFF, 0x8F, 0x1F, 0xFC, 0x3F, 0xF8, 0x71, 0xFF, 0xFF,    \
        0x8E, 0x1F, 0xFC, 0x3F, 0xF8, 0x38, 0xFE, 0x7F, 0x1C, 0x1F, 0xFC, 0x1F, 0xF8, 0x38, 0x7F, 0xFE, 0x1C, 0x1F, 0xFC, 0x1F,    \
        0xF8, 0x38, 0x3F, 0xFC, 0x1C, 0x1F, 0xFC, 0x1F, 0xF8, 0x18, 0x1F, 0xF8, 0x18, 0x1F, 0xF8, 0x1F, 0xF8, 0x18, 0x1F, 0xF8,    \
        0x18, 0x1F, 0xF8, 0x1F, 0xF8, 0x18, 0x3F, 0xFC, 0x1C, 0x1F, 0xF8, 0x1F, 0xF8, 0x38, 0x7F, 0xFE, 0x1C, 0x1F, 0xFC, 0x3F,    \
        0xF8, 0x38, 0xFE, 0x7F, 0x1C, 0x1F, 0xFC, 0x3F, 0xF8, 0x39, 0xFF, 0xFF, 0x9C, 0x1F, 0xFC, 0x3F, 0xF8, 0xF1, 0xFF, 0xFF,    \
        0x8F, 0x1F, 0xFC, 0x3F, 0xF0, 0xF1, 0xFF, 0xFF, 0x8F, 0x0F, 0xFC, 0x3F, 0xF0, 0xE3, 0xEF, 0xF7, 0xC7, 0x0F, 0xFC, 0x7F,    \
        0xF0, 0xF7, 0x07, 0xE0, 0xEF, 0x0F, 0xFE, 0x7F, 0xE0, 0xFF, 0x07, 0xE0, 0xFF, 0x07, 0xFE, 0xFF, 0xE0, 0xFF, 0x3F, 0xFC,    \
        0xFF, 0x07, 0xFF, 0xFF, 0xC0, 0xFF, 0xFE, 0x7F, 0xFF, 0x03, 0xFF, 0xFF, 0x80, 0x7F, 0xF8, 0x1F, 0xFE, 0x81, 0xFF, 0xFF,    \
        0x81, 0xFF, 0x00, 0x00, 0xFF, 0x80, 0xFF, 0xFF, 0x03, 0xFF, 0x01, 0x80, 0xFF, 0xC0, 0xFF, 0xFF, 0x03, 0xFE, 0x0F, 0xF0,    \
        0x7F, 0xC0, 0xFF, 0xFF, 0x07, 0xFC, 0xFF, 0xFF, 0x1F, 0xE0, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xFF,    \
        0x1F, 0xE0, 0xFF, 0xFF, 0x07, 0xF8, 0xFF, 0xFF, 0x3F, 0x80, 0xFF, 0xFF, 0x01, 0xFC, 0xFF, 0xFF, 0x7F, 0x00, 0xFC, 0x3F,    \
        0x00, 0xFE, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0x03, 0x00, 0x00, 0xC0, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0x07, 0x00, 0x00, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0x3F, 0x00, 0x00, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x3F, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,    \
        0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
